@@ -2,6 +2,7 @@ from .tracecontext import TraceContext
 from .context import Context
 from .meta import check_input_type_annotation
 from .meta import check_output_type_annotation
+from .meta import has_implicit_output
 from .meta import is_trigger_binding
 from .meta import from_incoming_proto, to_outgoing_proto
 from .out import Out
@@ -11,5 +12,6 @@ __all__ = (
     'Out', 'Context',
     'is_trigger_binding',
     'check_input_type_annotation', 'check_output_type_annotation',
+    'has_implicit_output',
     'from_incoming_proto', 'to_outgoing_proto', 'TraceContext',
 )
